pub struct NativePollQuery {
pub state: String,
}Expand description
Query params for GET /native/callback and GET /native/poll — the
RFC 8252 7.1-style native-app flow where the server hosts the OAuth
redirect_uri (a real HTTPS URL, not a client-run loopback listener) and
the desktop client polls for the resulting code by state.
Fields
state: StringTrait Implementations
Sourceimpl Clone for NativePollQuery
impl Clone for NativePollQuery
Sourcefn clone(&self) -> NativePollQuery
fn clone(&self) -> NativePollQuery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NativePollQuery
impl Debug for NativePollQuery
Sourceimpl<'de> Deserialize<'de> for NativePollQuery
impl<'de> Deserialize<'de> for NativePollQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NativePollQuery
impl PartialEq for NativePollQuery
Sourcefn eq(&self, other: &NativePollQuery) -> bool
fn eq(&self, other: &NativePollQuery) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NativePollQuery
impl Serialize for NativePollQuery
impl Eq for NativePollQuery
impl StructuralPartialEq for NativePollQuery